package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcDeviceExpenseMapper;
import com.ruoyi.oa.domain.CmcDeviceExpense;
import com.ruoyi.oa.service.ICmcDeviceExpenseService;

/**
 * cmc设备费用Service业务层处理
 * 
 * @author cmc
 * @date 2024-05-21
 */
@Service
public class CmcDeviceExpenseServiceImpl implements ICmcDeviceExpenseService 
{
    @Autowired
    private CmcDeviceExpenseMapper cmcDeviceExpenseMapper;

    /**
     * 查询cmc设备费用
     * 
     * @param deviceExpenseId cmc设备费用主键
     * @return cmc设备费用
     */
    @Override
    public CmcDeviceExpense selectCmcDeviceExpenseByDeviceExpenseId(Integer deviceExpenseId)
    {
        return cmcDeviceExpenseMapper.selectCmcDeviceExpenseByDeviceExpenseId(deviceExpenseId);
    }

    /**
     * 查询cmc设备费用列表
     * 
     * @param cmcDeviceExpense cmc设备费用
     * @return cmc设备费用
     */
    @Override
    public List<CmcDeviceExpense> selectCmcDeviceExpenseList(CmcDeviceExpense cmcDeviceExpense)
    {
        return cmcDeviceExpenseMapper.selectCmcDeviceExpenseList(cmcDeviceExpense);
    }

    /**
     * 新增cmc设备费用
     * 
     * @param cmcDeviceExpense cmc设备费用
     * @return 结果
     */
    @Override
    public int insertCmcDeviceExpense(CmcDeviceExpense cmcDeviceExpense)
    {
        return cmcDeviceExpenseMapper.insertCmcDeviceExpense(cmcDeviceExpense);
    }

    /**
     * 修改cmc设备费用
     * 
     * @param cmcDeviceExpense cmc设备费用
     * @return 结果
     */
    @Override
    public int updateCmcDeviceExpense(CmcDeviceExpense cmcDeviceExpense)
    {
        return cmcDeviceExpenseMapper.updateCmcDeviceExpense(cmcDeviceExpense);
    }

    /**
     * 批量删除cmc设备费用
     * 
     * @param deviceExpenseIds 需要删除的cmc设备费用主键
     * @return 结果
     */
    @Override
    public int deleteCmcDeviceExpenseByDeviceExpenseIds(Integer[] deviceExpenseIds)
    {
        return cmcDeviceExpenseMapper.deleteCmcDeviceExpenseByDeviceExpenseIds(deviceExpenseIds);
    }

    /**
     * 删除cmc设备费用信息
     * 
     * @param deviceExpenseId cmc设备费用主键
     * @return 结果
     */
    @Override
    public int deleteCmcDeviceExpenseByDeviceExpenseId(Integer deviceExpenseId)
    {
        return cmcDeviceExpenseMapper.deleteCmcDeviceExpenseByDeviceExpenseId(deviceExpenseId);
    }
}
